@@ -230,7 +230,8 @@ static ScalarType EdgeLenghtVariationIfVertexRotated(const FaceType &f, int w0)
     pi = pf->cFFi( pi );
     pi = (pi+1)%3; // FaceType::Next( pf->FFi( pi ) );
     pf = t;
-    assert(guard++<100);
+    guard++;
+    assert(guard<100);
   } while (pf != &f);
   assert (na == n);
   return (after-before);
@@ -251,8 +252,6 @@ static ScalarType QuadQualityVariationIfVertexRotated(const FaceType &f, int w0)
   // rotate arond vertex
   const FaceType* pf = &f;
   int pi = w0;
-  int nb = 0; // vertex valency
-  int na = 0;
   std::vector<const VertexType *> s; // 1 star around v
   do {
     // ScalarType triEdge = (pf->P0(pi) - pf->P1(pi) ).Norm();
@@ -272,7 +271,8 @@ static ScalarType QuadQualityVariationIfVertexRotated(const FaceType &f, int w0)
     pi = pf->cFFi( pi );
     pi = (pi+1)%3; // FaceType::Next( pf->FFi( pi ) );
     pf = t;
-    assert(guard++<100);
+    guard++;
+    assert(guard<100);
   } while (pf != &f);
 
   assert(s.size()%2==0);
@@ -285,7 +285,6 @@ static ScalarType QuadQualityVariationIfVertexRotated(const FaceType &f, int w0)
     after+=quadQuality( s[h]->P(),s[i]->P(),s[j]->P(),f.P(w0) );
   }
 
-  assert (na == nb);
   return (after-before);
 }
 
@@ -595,7 +594,8 @@ static bool IsDoubletFF(const FaceType& f, int wedge){
     pi = pf->cFFi( pi );
     pi = (pi+1)%3; // FaceType::Next( pf->FFi( pi ) );
     pf = t;
-    assert(guard++<100);
+    guard++;
+    assert(guard<100);
   } while (pf != &f);
   return (res == 2);
 }
@@ -631,7 +631,8 @@ static bool IsSingletFF(const FaceType& f, int wedge){
     pi = pf->cFFi( pi );
     pi = (pi+1)%3; // FaceType::Next( pf->FFi( pi ) );
     pf = t;
-    assert(guard++<100);
+    guard++;
+    assert(guard<100);
   } while (pf != &f);
   return (res == 1);
 }
